@@ -1,7 +1,6 @@
 import os
 import platform
 import inspect
-import utils
 
 class IO:
     """
@@ -42,39 +41,32 @@ class IO:
         self.OUT = []
 
     def write(self, *params, **keys):
-        sep = keys.get('separator')
-        if sep is None: sep = ' '
         l = len(self.IN)
         if l == 0:
             self.IN.append([])
         arr = self.IN[-1]
-        arr.append({'sep': sep, 'ele': params})
+        arr.extend(params)
     
-    def writeln(self, *params, **keys):
-        sep = keys.get('separator')
-        if sep is None: sep = ' '
+    def writeln(self, *params):
         l = len(self.IN)
         if l == 0:
             self.IN.append([])
         arr = self.IN[-1]
-        arr.append({'sep': sep, 'ele': params})
+        arr.extend(params)
         self.IN.append([])
 
     def _writeDataIntoFile(self, fp, data):
         t = type(data)
-        if t is dict:
-            print(data)
-            for d in data['ele']:
-                self._writeDataIntoFile(fp, d)
-                fp.write(data['sep'])   # 在每个元素后都输出分割符
-        elif t is str:
+        if t is str:
             data = data.strip()
             fp.write(str(data))
+            fp.write(" ")
         elif t is list or t is tuple:
             for d in data:
                 self._writeDataIntoFile(fp, d)
         else:
             fp.write(str(data))
+            fp.write(" ")
 
     def _processData(self, func, id, isdefault):
         self.resetIO()
